@@ -22,7 +22,7 @@
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Header.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
@@ -49,6 +49,9 @@ namespace Lum {
   class LUMAPI Combo : public Control
   {
   private:
+    /**
+      The selection popup
+      */
     class ComboPopup : public Popup
     {
     public:
@@ -63,22 +66,19 @@ namespace Lum {
     };
 
   private:
-    bool                          imageRight;
-    bool                          editable;
-    Table                         *table;
-    ComboPopup*                   popup;
+    bool                          imageRight;   //! If true, image should be displayed to the right (else left)
+    bool                          editable;     //! If true, the combobox is editable
+    Table                         *table;       //! The table control in the popup
+    ComboPopup*                   popup;        //! The selection popup
 
   protected:
-    Model::ActionRef              prevAction;
-    Model::ActionRef              nextAction;
-    Model::HeaderRef              headerModel; /** The header model used for the table in the popup */
-    Model::TableRef               tableModel;  /** The table model used for the table in the popup */
+    Model::ActionRef              prevAction;   //! Model trigger if previous element should be selected
+    Model::ActionRef              nextAction;   //! Model trigger if next element should be selected
+    Model::HeaderRef              headerModel;  //! The header model used for the table in the popup
+    Model::TableRef               tableModel;   //! The table model used for the table in the popup
+    TableCellPainterRef           tablePainter; //! The table painter for the popup table
     Model::SingleLineSelectionRef selection;
-    Object                        *value; /**
-                                           The object used to display the current
-                                           value. This might even allow implace
-                                           editing like for example @otype{S.String}.
-                                          */
+    Object                        *value;       //! Value editing control for read-write combobox
 
   private:
     void OpenPopup();
@@ -88,18 +88,22 @@ namespace Lum {
     Combo(Object* value, bool editable);
     virtual ~Combo();
 
-    virtual void CopySelection(size_t row) = 0;
+    void PreparePainter(ValuePainter* painter);
+
+    virtual void SetModelFromSelection() = 0;
+    virtual void SetSelectionFromModel() = 0;
 
   public:
     bool HasBaseline() const;
     size_t GetBaseline() const;
 
-    Object* GetFocusObject();
+    Object* GetValueObject() const;
 
     bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
     void SetHeaderModel(Model::Header* model);
     void SetTableModel(Model::Table* model);
+    void SetTableCellPainter(TableCellPainter *tablePainter);
 
     void CalcSize();
     void Layout();
@@ -108,12 +112,10 @@ namespace Lum {
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
     void PrepareForBackground(OS::DrawInfo* draw);
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
     void Hide();
 
-    void DrawFocus();
-    void HideFocus();
-
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
 
@@ -123,15 +125,14 @@ namespace Lum {
     Model::StringRef model; /** The model for the current value */
 
   protected:
-    void CopySelection(size_t row);
+    void SetModelFromSelection();
+    void SetSelectionFromModel();
 
   public:
     TextCombo();
     ~TextCombo();
 
     bool SetModel(Base::Model* model);
-
-    void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
 
   class LUMAPI IndexCombo : public Combo
@@ -140,7 +141,8 @@ namespace Lum {
     Model::SizeTRef model; /** The model for the current value */
 
   protected:
-    void CopySelection(size_t row);
+    void SetModelFromSelection();
+    void SetSelectionFromModel();
 
   public:
     IndexCombo();
@@ -148,8 +150,6 @@ namespace Lum {
 
     bool SetModel(Base::Model* model);
 
-    void Resync(Base::Model* model, const Base::ResyncMsg& msg);
-
     static IndexCombo* Create(Lum::Model::SizeT* index, Lum::Model::Table* table,
                               bool horizontalFlex=false, bool verticalFlex=false);
   };
@@ -161,7 +161,8 @@ namespace Lum {
     Model::StringRef model; /** The model for the current value */
 
   protected:
-    void CopySelection(size_t row);
+    void SetModelFromSelection();
+    void SetSelectionFromModel();
 
   public:
     TextEditCombo();
