@@ -20,12 +20,12 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
 namespace Lum {
   namespace Dlg {
 
-    class LUMAPI Help : public Dialog
+    class LUMAPI Help : public Dlg::ActionDialog
     {
     private:
       std::wstring helpText;
@@ -34,7 +34,8 @@ namespace Lum {
       Help(const std::wstring& helpText);
       ~Help();
 
-      void PreInit();
+      Lum::Object* GetContent();
+      void GetActions(std::vector<ActionInfo>& actions);
 
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
 
