@@ -68,7 +68,8 @@ namespace Lum {
     bool HandleMouseEvent(const OS::MouseEvent& event);
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
     void Hide();
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
