@@ -22,7 +22,7 @@
 
 #include <Lum/Base/Model.h>
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 namespace Lum {
   namespace Model {
