@@ -84,9 +84,6 @@ namespace Lum {
 
       virtual size_t GetRows() const = 0;
 
-      virtual std::wstring GetString(size_t column, size_t row) const = 0;
-      virtual Lum::Object* GetObject(size_t column, size_t row) const = 0;
-
       virtual bool Sort(size_t column, bool down=true);
     };
 
@@ -101,7 +98,7 @@ namespace Lum {
       containers.
      */
     template<typename Element, typename Container>
-    class LUMAPI StdTableBase : public Table
+    class StdTableBase : public Table
     {
     public:
       typedef Container                                  ContainerType;
@@ -109,33 +106,11 @@ namespace Lum {
       typedef typename ContainerType::iterator           Iterator;
 
     public:
-      /**
-        Maps element to the to be displayed data (eitehr string or an object).
-       */
-      class LUMAPI DataProvider
-      {
-      public:
-        virtual ~DataProvider()
-        {
-          // no code
-        }
-
-        virtual std::wstring GetString(const Iterator& /*iter*/, size_t /*column*/) const
-        {
-          return L"";
-        }
-
-        virtual Lum::Object* GetObject(const Iterator& /*iter*/, size_t /*column*/) const
-        {
-          return NULL;
-        }
-      };
-
       /**
         Optionally assignable function object for sorting of tables. If no Comp
         no sorting is possible.
        */
-      class LUMAPI Comparator
+      class Comparator
       {
       public:
         virtual bool operator()(const Element& a, const Element& b, size_t column, bool down) const = 0;
@@ -171,7 +146,6 @@ namespace Lum {
       mutable Iterator current;
       mutable size_t   currentPos;
       mutable bool     currentInvalid;
-      DataProvider     *dataProvider;
       Comparator       *comparator;
 
     private:
@@ -211,10 +185,9 @@ namespace Lum {
       virtual Container& GetContainer() = 0;
       virtual const Container& GetContainer() const = 0;
 
-      StdTableBase(DataProvider* dataProvider, Comparator* comparator=NULL)
+      StdTableBase(Comparator* comparator=NULL)
        : currentPos(0),
          currentInvalid(true),
-         dataProvider(dataProvider),
          comparator(comparator)
       {
         // no code
@@ -222,7 +195,6 @@ namespace Lum {
 
       ~StdTableBase()
       {
-        delete dataProvider;
         delete comparator;
       }
 
@@ -248,18 +220,6 @@ namespace Lum {
         return *current;
       }
 
-      std::wstring GetString(size_t column, size_t row) const
-      {
-        GotoEntry(row);
-        return dataProvider->GetString(current,column);
-      }
-
-      Lum::Object* GetObject(size_t column, size_t row) const
-      {
-        GotoEntry(row);
-        return dataProvider->GetObject(current,column);
-      }
-
       // Insert
       // SwapWithNext
       virtual Element Delete(size_t row)
@@ -317,12 +277,11 @@ namespace Lum {
     };
 
     template<typename Element, typename Container>
-    class LUMAPI StdTableBaseSorted : public StdTableBase<Element,Container>
+    class StdTableBaseSorted : public StdTableBase<Element,Container>
     {
     public:
-      StdTableBaseSorted(typename StdTableBase<Element, Container>::DataProvider* dataProvider,
-                         typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
-       : StdTableBase<Element,Container>(dataProvider,comparator)
+      StdTableBaseSorted(typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
+       : StdTableBase<Element,Container>(comparator)
       {
         // no code
       }
@@ -347,12 +306,11 @@ namespace Lum {
     };
 
     template <typename Element>
-    class LUMAPI StdTableBaseSorted<Element,std::list<Element> > : public StdTableBase<Element,std::list<Element> >
+    class StdTableBaseSorted<Element,std::list<Element> > : public StdTableBase<Element,std::list<Element> >
     {
     public:
-      StdTableBaseSorted(typename StdTableBase<Element,std::list<Element> >::DataProvider* dataProvider,
-                         typename StdTableBase<Element,std::list<Element> >::Comparator* comparator=NULL)
-       : StdTableBase<Element,std::list<Element> >(dataProvider,comparator)
+      StdTableBaseSorted(typename StdTableBase<Element,std::list<Element> >::Comparator* comparator=NULL)
+       : StdTableBase<Element,std::list<Element> >(comparator)
       {
         // no code
       }
@@ -379,16 +337,15 @@ namespace Lum {
       Container holding elements of type Element.
      */
     template<typename Element, typename Container = std::list<Element> >
-    class LUMAPI StdTable : public StdTableBaseSorted<Element,Container>
+    class StdTable : public StdTableBaseSorted<Element,Container>
     {
 
     private:
       mutable typename StdTableBase<Element, Container>::ContainerType container;
 
     public:
-      StdTable(typename StdTableBase<Element, Container>::DataProvider* dataProvider,
-               typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
-       : StdTableBaseSorted<Element,Container>(dataProvider,comparator)
+      StdTable(typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
+       : StdTableBaseSorted<Element,Container>(comparator)
       {
         // no code
       }
@@ -411,16 +368,15 @@ namespace Lum {
       this element.
      */
     template<typename Element, typename Container = std::list<Element> >
-    class LUMAPI StdPtrTable : public StdTableBaseSorted<Element,Container>
+    class StdPtrTable : public StdTableBaseSorted<Element,Container>
     {
 
     private:
       mutable typename StdTableBase<Element, Container>::ContainerType container;
 
     public:
-      StdPtrTable(typename StdTableBase<Element, Container>::DataProvider* dataProvider,
-               typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
-       : StdTableBaseSorted<Element,Container>(dataProvider,comparator)
+      StdPtrTable(typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
+       : StdTableBaseSorted<Element,Container>(comparator)
       {
         // no code
       }
@@ -461,7 +417,7 @@ namespace Lum {
       The reference to the container instance is passed in the constructor.
      */
     template<typename Element, typename Container = std::list<Element> >
-    class LUMAPI StdRefTable : public StdTableBaseSorted<Element,Container>
+    class StdRefTable : public StdTableBaseSorted<Element,Container>
     {
 
     private:
@@ -469,9 +425,8 @@ namespace Lum {
 
     public:
       StdRefTable(typename StdTableBase<Element, Container>::ContainerType& container,
-                  typename StdTableBase<Element, Container>::DataProvider* dataProvider,
                   typename StdTableBase<Element, Container>::Comparator* comparator=NULL)
-       : StdTableBaseSorted<Element,Container>(dataProvider,comparator),
+       : StdTableBaseSorted<Element,Container>(comparator),
          container(container)
       {
         // no code
@@ -493,18 +448,9 @@ namespace Lum {
      */
     class LUMAPI StringTable : public StdTable<std::wstring, std::list<std::wstring> >
     {
-    public:
-      class StringDataProvider : public StdTable<std::wstring, std::list<std::wstring> >::DataProvider
-      {
-        std::wstring GetString(const StringTable::Iterator& iter, size_t /*column*/) const
-        {
-          return *iter;
-        }
-      };
-
     public:
       StringTable()
-      : StdTable<std::wstring, std::list<std::wstring> >(new StringDataProvider())
+      : StdTable<std::wstring, std::list<std::wstring> >(NULL)
       {
         // no code
       }
@@ -517,18 +463,9 @@ namespace Lum {
      */
     class LUMAPI StringRefTable : public StdRefTable<std::wstring,std::list<std::wstring> >
     {
-    public:
-      class StringRefDataProvider : public StdRefTable<std::wstring,std::list<std::wstring> >::DataProvider
-      {
-        std::wstring GetString(const StringRefTable::Iterator& iter, size_t /*column*/) const
-        {
-          return *iter;
-        }
-      };
-
     public:
       StringRefTable(std::list<std::wstring>& container)
-      : StdRefTable<std::wstring, std::list<std::wstring> >(container,new StringRefDataProvider())
+      : StdRefTable<std::wstring, std::list<std::wstring> >(container,NULL)
       {
         // no code
       }
@@ -542,48 +479,15 @@ namespace Lum {
      */
     class LUMAPI StringMatrix : public StdTable<std::vector<std::wstring>, std::list<std::vector<std::wstring> > >
     {
-    public:
-      class StringMatrixDataProvider : public StdTable<std::vector<std::wstring>, std::list<std::vector<std::wstring> > >::DataProvider
-      {
-        std::wstring GetString(const StringMatrix::Iterator& iter, size_t column) const
-        {
-          return (*iter)[column-1];
-        }
-      };
-
     public:
       StringMatrix()
-      : StdTable<std::vector<std::wstring>, std::list<std::vector<std::wstring> > >(new StringMatrixDataProvider())
+      : StdTable<std::vector<std::wstring>, std::list<std::vector<std::wstring> > >(NULL)
       {
         // no code
       }
     };
 
     typedef Base::Reference<StringMatrix> StringMatrixRef;
-
-    /**
-      Predefined table model implementation based on StdTable for a list of object (pointers).
-     */
-    class LUMAPI ObjectTable : public StdTable<Lum::Object*, std::list<Lum::Object*> >
-    {
-    public:
-      class ObjectDataProvider : public StdTable<Lum::Object*, std::list<Lum::Object*> >::DataProvider
-      {
-        Lum::Object* GetObject(const ObjectTable::Iterator& iter, size_t /*column*/) const
-        {
-          return *iter;
-        }
-      };
-
-    public:
-      ObjectTable()
-      : StdTable<Lum::Object*, std::list<Lum::Object*> >(new ObjectDataProvider())
-      {
-        // no code
-      }
-    };
-
-    typedef Base::Reference<ObjectTable> ObjectTableRef;
   }
 }
 
