@@ -20,17 +20,13 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/OS/Behaviour.h>
+#include <Lum/Manager/Behaviour.h>
 
 namespace Lum {
   namespace OS {
     namespace Base {
 
-      class Behaviour : public OS::Behaviour
-      {
-      };
-
-      class DefaultBehaviour : public Behaviour
+      class DefaultBehaviour : public Lum::Manager::Behaviour
       {
       public:
         DefaultBehaviour();
@@ -38,18 +34,29 @@ namespace Lum {
 
         bool FocusObjectOnWindowFocusIn() const;
         bool ScrollKnobActive() const;
+        TableActionMode GetTableDefaultActionMode() const;
 
         CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
         void ApplyMultiViewDlg(Dialog* dialog,
                                const Def::MultiView& multiView) const;
 
-        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
-        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def,
+        Lum::Object* GetActionControl(const Def::Action& def) const;
+        Lum::Object* GetActionControl(const Def::Action& def,
+                                      bool horizFlex,
+                                      bool vertFlex) const;
+
+        Lum::Object* GetOneOfNControl(const Def::OneOfN& def) const;
+        Lum::Object* GetOneOfNControl(const Def::OneOfN& def,
+                                      bool horizFlex,
+                                      bool vertFlex) const;
+
+        Lum::Object* GetOneOfManyControl(const Def::OneOfMany& def) const;
+        Lum::Object* GetOneOfManyControl(const Def::OneOfMany& def,
                                          bool horizFlex,
                                          bool vertFlex) const;
 
-        Lum::Object* GetBooleanControl(Def::Boolean& def) const;
-        Lum::Object* GetBooleanControl(Def::Boolean& def,
+        Lum::Object* GetBooleanControl(const Def::Boolean& def) const;
+        Lum::Object* GetBooleanControl(const Def::Boolean& def,
                                        bool horizFlex,
                                        bool vertFlex) const;
       };
