@@ -46,7 +46,7 @@ namespace Lum {
         Model::ActionRef     focusOutAction;   //! Triggered when the window has lost the focus
         Model::ActionRef     mouseInAction;    //! Triggered when the window gets the focus
         Model::ActionRef     mouseOutAction;   //! Triggered when the window has lost the focus
-        Model::ActionRef     redrawAction;     //! Triggered when the window has to be refreshed
+        Model::ActionRef     drawAction;       //! Triggered when the application wants to redraw a given area
         Model::ActionRef     resizeAction;     //! Triggered when the window has been resized
         Model::ActionRef     preInitAction;    //! Triggered before the window initially opens
         Model::ActionRef     eventAction;      //! Triggered for every low-level event
@@ -95,8 +95,6 @@ namespace Lum {
         void SetParent(OS::Window* parent);
         OS::Window* GetParent() const;
 
-        OS::DrawInfo* GetDrawInfo() const;
-
         void SetType(OS::Window::Type type);
         OS::Window::Type GetType() const;
 
@@ -137,7 +135,7 @@ namespace Lum {
         Model::Action* GetMouseInAction() const;
         Model::Action* GetMouseOutAction() const;
         Model::Action* GetResizeAction() const;
-        Model::Action* GetRedrawAction() const;
+        Model::Action* GetDrawAction() const;
         Model::Action* GetPreInitAction() const;
         Model::Action* GetEventAction() const;
         Model::Action* GetGrabCancelAction() const;
@@ -180,7 +178,10 @@ namespace Lum {
         bool LeaveFullScreen();
         bool IsFullScreen() const;
 
-        bool SwitchBackgroundDrawInfo(int x, int y, size_t width, size_t height);
+        DrawInfo* RequestDrawInfo(int x, int y, size_t width, size_t height);
+        void ReleaseDrawInfo(int x, int y, size_t width, size_t height);
+        DrawInfo* RequestRefreshDrawInfo(int x, int y, size_t width, size_t height);
+        void ReleaseRefreshDrawInfo(int x, int y, size_t width, size_t height);
 
         void TriggerMaped();
         void TriggerUnmaped();
@@ -193,7 +194,6 @@ namespace Lum {
         void TriggerMouseIn();
         void TriggerMouseOut();
         void TriggerResize(size_t width, size_t height);
-        void TriggerRedraw(int x, int y, size_t width, size_t height);
         void TriggerGrabCancel();
         void TriggerMenu();
 
