@@ -71,12 +71,13 @@ namespace Lum {
         std::stack<FontEntry> fontStack;
         size_t                colorPushCount;
         size_t                dashPushCount;
-        
+/*
+#if defined(__APPLE__)
+        CGContextRef       context;
+#endif*/
       protected:
         void SetDefaults();
 
-        virtual void GetRGBValue(Color color, double &r, double &g, double &b) = 0;
-
       public:
         DrawInfo(OS::Window* window);
         DrawInfo(OS::Bitmap* bitmap);
@@ -146,6 +147,7 @@ namespace Lum {
 
       public:
         Win32DrawInfo(OS::Window* window);
+        Win32DrawInfo(OS::Window* window, HDC dc);
         Win32DrawInfo(OS::Bitmap* bitmap);
 
         ~Win32DrawInfo();
@@ -159,9 +161,6 @@ namespace Lum {
         ::Display *display;
         ::Window  drawable;
 
-      protected:
-        void GetRGBValue(Color color, double &r, double &g, double &b);
-
       public:
         X11DrawInfo(OS::Window* window);
         X11DrawInfo(OS::Bitmap* bitmap);
