@@ -118,6 +118,16 @@ namespace Lum {
   class LUMAPI Object : public Base::DataExchangeObject
   {
   public:
+    static const wchar_t* inputTypeAlpha;
+    static const wchar_t* inputTypeUnsignedBinaryNumber;
+    static const wchar_t* inputTypeUnsignedOctalNumber;
+    static const wchar_t* inputTypeSignedDecimalNumber;
+    static const wchar_t* inputTypeUnsignedDecimalNumber;
+    static const wchar_t* inputTypeUnsignedHexadecimalNumber;
+    static const wchar_t* inputTypeSignedFloatNumber;
+    static const wchar_t* inputTypeUnsignedFloatNumber;
+    static const wchar_t* inputTypePhoneNumber;
+
     enum Constraint
     {
       constraintMinWidth,
@@ -190,12 +200,14 @@ namespace Lum {
     bool                visible;        //! The object is currently visible
     bool                firstDraw;      //! If true, this is the first drawing of the widget
     bool                layouted;       //! The object has calculated its layout (can be reseted by move/resize)
-    bool                clipFromParent; //! Parent objects must not draw into the area of this object (drawing of parent must be cliped)
 
   private:
+    bool                clipFromParent; //! Parent objects must not draw into the area of this object (drawing of parent must be cliped)
+    bool                clipBackgroundToBorder; //! Draw only the border part of the background
+
     /**
-      @name Keyboard focus.
-      A number of flags that handle keyboard focus behaviour.
+      @name Input focus.
+      A number of flags that handle input focus behaviour.
     */
     //@{
     bool                hasFocus;      //! The object currently has the focus
@@ -217,6 +229,9 @@ namespace Lum {
     std::list<ConstraintSize> constraints;
     //@}
 
+    std::wstring        inputTypeHint; //! Optional information about the type of input
+                                       //! to evaluated for virtual keyboards
+
   public:
     bool                inited;        //! Has been initialized
     bool                shortcutAlways;
@@ -253,6 +268,7 @@ namespace Lum {
 
     virtual void SetRedrawOnMouseActive(bool redraw);
     virtual void SetClipFromParent(bool clip);
+    virtual void SetClipBackgroundToBorder(bool clip);
 
     virtual void DrawChildren(OS::DrawInfo* draw, int x, int y, size_t w, size_t h);
     virtual void PreDrawChilds(OS::DrawInfo* draw);
@@ -367,7 +383,6 @@ namespace Lum {
     virtual void SetWindow(OS::Window* window);
     virtual OS::Window* GetWindow() const;
 
-    virtual OS::DrawInfo* GetDrawInfo() const;
     //@}
 
     /**
@@ -396,8 +411,9 @@ namespace Lum {
     //@{
     virtual bool HasFocus() const;
     virtual bool CanFocus() const;
-    virtual bool DisplayFocus() const;
-    virtual bool HandlesFocus() const;
+    virtual bool ShowFocus() const;
+    virtual bool HandlesClickFocus() const;
+    virtual bool HandlesKeyFocus() const;
     virtual void SetRequestLabelFocus(bool request);
     virtual bool RequestsLabelFocus() const;
 
@@ -406,10 +422,6 @@ namespace Lum {
 
     virtual bool RequestedFocus() const;
 
-    virtual void SetRequestsKeyboard(bool request);
-    virtual bool RequestsKeyboard() const;
-    virtual IMHandler* GetIMHandler();
-
     virtual Object* GetFocusFirst();
     virtual Object* GetFocusLast();
     virtual Object* GetFocusNext(Object* object);
@@ -433,6 +445,17 @@ namespace Lum {
     virtual bool HasImplicitLabel() const;
     //@}
 
+    /**
+      @name Input handling methods
+    */
+    //@{
+    virtual void SetRequestsKeyboard(bool request);
+    virtual bool RequestsKeyboard() const;
+    virtual Object* SetInputTypeHint(const std::wstring& inputTypeHint);
+    virtual std::wstring GetInputTypeHint() const;
+    virtual IMHandler* GetIMHandler();
+    //@}
+
     virtual bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
 
@@ -479,14 +502,24 @@ namespace Lum {
     virtual void PrepareForBackground(OS::DrawInfo* draw);
     void DrawBackground(OS::DrawInfo* draw,
                         int x, int y, size_t w, size_t h);
-    virtual OS::Color GetTextColor(OS::DrawInfo *draw) const;
+    //@}
+
+    /**
+      @name Drawing style for object and its children
+    */
+    virtual OS::Color GetTextColor(OS::DrawInfo* draw,
+                                   const void* child) const;
+    virtual OS::Font* GetFont(const void* child) const;
+    virtual unsigned long GetFontStyle(const void* child) const;
+    virtual bool GetFontStyleSmart(const void* child) const;
     //@}
 
     /**
       @name Object drawing methods
     */
     //@{
-    virtual void Draw(int x, int y, size_t w, size_t h);
+    virtual void Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h);
     virtual void Redraw();
     virtual void Redraw(int x, int y, size_t w, size_t h);
     virtual void Hide();
@@ -531,7 +564,8 @@ namespace Lum {
   public:
     ~Control();
 
-    virtual bool HandlesFocus() const;
+    bool HandlesClickFocus() const;
+    bool HandlesKeyFocus() const;
 
     // Setter
     virtual bool SetModel(Base::Model* model);
@@ -539,26 +573,36 @@ namespace Lum {
     // Getter
     Base::Model* GetModel() const;
 
+    bool HasModel() const;
+
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
 
   /**
-    Objects that can scoll their content
+    Objects that can scoll their content.
+
+    Scrollables must assure that they set the adjustments to their
+    current and correct values in the Layout() methods. The parent
+    control on the other hand  must call Layout() with the dimensions
+    of the Scrollable correctly set before. This way the parent
+    control should be able to decide if scrolling bars should be shown
+    or not.
   */
   class LUMAPI Scrollable : public Control
   {
   protected:
     Model::AdjustmentRef hAdjustment;
     Model::AdjustmentRef vAdjustment;
-    Model::ActionRef     updateDimensionsAction;
+    Object*              scrollView;
 
   protected:
-    virtual void UpdateDimensions() = 0;
+    virtual void GetDimension(size_t& width, size_t& height) = 0;
 
   public:
     Scrollable();
     ~Scrollable();
 
+    virtual void GetODimension(size_t& width, size_t& height);
     virtual bool RequiresKnobs() const;
 
     void SetHAdjustment(Model::Adjustment* adjustment);
@@ -567,10 +611,10 @@ namespace Lum {
     Model::Adjustment* GetHAdjustment() const;
     Model::Adjustment* GetVAdjustment() const;
 
-    void Layout();
-    void Draw(int x, int y, size_t w, size_t h);
+    void SetScrollView(Object *scrollView);
 
-    void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+    void Redraw();
+    void Redraw(int x, int y, size_t w, size_t h);
   };
 
   /**
