@@ -20,7 +20,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/Time.h>
 
 #include <Lum/Object.h>
