@@ -23,16 +23,22 @@
 
 #include <Lum/Base/String.h>
 
-#include <assert.h>
-#include <stddef.h>
-#include <string.h>
-#include <time.h>
+#include <cassert>
+#include <cstddef>
+#include <cstring>
+
 #if defined(__WIN32__) || defined(WIN32)
   #include <Lum/OS/Win32/OSAPI.h>
 #else
   #include <unistd.h>
 #endif
 
+#include <Lum/Private/Config.h>
+
+#if defined(HAVE_SYS_TIME_H)
+  #include <sys/time.h>
+#endif
+
 #if defined(__WIN32__) && !defined(__MINGW32__)
 struct timezone {
    int tz_minuteswest; /* of Greenwich */
@@ -459,41 +465,53 @@ namespace Lum {
       }
     }
 
-    SystemTime::SystemTime()
+    struct SystemTime::SystemTimePIMPL
     {
-      gettimeofday(&time,NULL);
+      timeval time;
+    };
+
+    SystemTime::SystemTime()
+    : pimpl(new SystemTimePIMPL())
+    {
+      gettimeofday(&pimpl->time,NULL);
+    }
+
+    SystemTime::SystemTime(const SystemTime& systemTime)
+    : pimpl(new SystemTimePIMPL())
+    {
+      *pimpl=*systemTime.pimpl;
     }
 
     SystemTime::SystemTime(time_t seconds, long microseconds)
+    : pimpl(new SystemTimePIMPL())
     {
       SetTime(seconds,microseconds);
     }
 
-    SystemTime::SystemTime(const timeval &t)
-    {
-      time=t;
-    }
-
 #if defined(__WIN32__) || defined(WIN32)
     SystemTime::SystemTime(const FILETIME& time)
+    : pimpl(new SystemTimePIMPL())
     {
       SetTime(time);
     }
 #endif
 
+    SystemTime& SystemTime::operator=(const SystemTime& systemTime)
+    {
+      // Works also with self-assignment!
+      *pimpl=*systemTime.pimpl;
+
+      return *this;
+    }
+
     time_t SystemTime::GetTime() const
     {
-      return time.tv_sec;
+      return pimpl->time.tv_sec;
     }
 
     long SystemTime::GetMicroseconds() const
     {
-      return time.tv_usec;
-    }
-
-    void SystemTime::GetTimeval(timeval& t)
-    {
-      t=time;
+      return pimpl->time.tv_usec;
     }
 
     void SystemTime::GetUTCDateTime(DateTime& dateTime) const throw (DateOutOfRange)
@@ -501,13 +519,13 @@ namespace Lum {
       struct tm utc;
       time_t    tmp;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_gmtime(tmp,&utc)) {
         throw DateOutOfRange();
       }
 
       assignTMToDateTime(dateTime,&utc);
-      dateTime.microsecond=time.tv_usec;
+      dateTime.microsecond=pimpl->time.tv_usec;
     }
 
     void SystemTime::GetLocalDateTime(DateTime& dateTime) const throw (DateOutOfRange)
@@ -515,13 +533,13 @@ namespace Lum {
       struct tm local;
       time_t    tmp;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
 
       assignTMToDateTime(dateTime,&local);
-      dateTime.microsecond=time.tv_usec;
+      dateTime.microsecond=pimpl->time.tv_usec;
     }
 
     int SystemTime::GetTimezone() const  throw (DateOutOfRange)
@@ -529,12 +547,12 @@ namespace Lum {
       time_t    u,l,tmp;
       struct tm utc,local;
 
-      tmp=time.tv_sec; // workaround non-const call
+      tmp=pimpl->time.tv_sec; // workaround non-const call
       if (!my_gmtime(tmp,&utc)) {
         throw DateOutOfRange();
       }
 
-      tmp=time.tv_sec; // workaround non-const call
+      tmp=pimpl->time.tv_sec; // workaround non-const call
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -559,12 +577,12 @@ namespace Lum {
       struct tm local1,local2;
       time_t    tmp,time1,time2;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local1)) {
         throw DateOutOfRange();
       }
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local2)) {
         throw DateOutOfRange();
       }
@@ -583,12 +601,12 @@ namespace Lum {
       struct tm local1,local2;
       time_t    tmp,time1,time2;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local1)) {
         throw DateOutOfRange();
       }
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local2)) {
         throw DateOutOfRange();
       }
@@ -607,12 +625,12 @@ namespace Lum {
       time_t    tmp,u,l;
       struct tm utc,local;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_gmtime(tmp,&utc)) {
         throw DateOutOfRange();
       }
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -640,7 +658,7 @@ namespace Lum {
       struct tm local;
       int       month,day;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -734,7 +752,7 @@ namespace Lum {
       time_t    tmp;
       struct tm local;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -747,7 +765,7 @@ namespace Lum {
       time_t    tmp;
       struct tm local;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -760,7 +778,7 @@ namespace Lum {
       time_t    tmp;
       struct tm local;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_localtime(tmp,&local)) {
         throw DateOutOfRange();
       }
@@ -777,7 +795,7 @@ namespace Lum {
       time_t    tmp;
       struct tm utc;
 
-      tmp=time.tv_sec;
+      tmp=pimpl->time.tv_sec;
       if (!my_gmtime(tmp,&utc)) {
         throw DateOutOfRange();
       }
@@ -787,24 +805,24 @@ namespace Lum {
 
     bool SystemTime::IsValid() const
     {
-      return (time.tv_sec!=0 || time.tv_usec!=0);
+      return (pimpl->time.tv_sec!=0 || pimpl->time.tv_usec!=0);
     }
 
     void SystemTime::Invalidate()
     {
-      time.tv_sec=0;
-      time.tv_usec=0;
+      pimpl->time.tv_sec=0;
+      pimpl->time.tv_usec=0;
     }
 
     void SystemTime::SetToNow()
     {
-      gettimeofday(&time,NULL);
+      gettimeofday(&pimpl->time,NULL);
     }
 
     void SystemTime::SetTime(time_t seconds, long microseconds)
     {
-      time.tv_sec=seconds;
-      time.tv_usec=microseconds;
+      pimpl->time.tv_sec=seconds;
+      pimpl->time.tv_usec=microseconds;
     }
 
 #if defined(__WIN32__) || defined(WIN32)
@@ -815,8 +833,8 @@ namespace Lum {
       _100ns.HighPart=time.dwHighDateTime;
       _100ns.QuadPart-=116444736000000000LL;
 
-      this->time.tv_usec=(long)((_100ns.QuadPart / 10LL) % 1000000LL );
-      this->time.tv_sec= (long)(_100ns.QuadPart/10000000LL);
+      pimpl->time.tv_usec=(long)((_100ns.QuadPart / 10LL) % 1000000LL );
+      pimpl->time.tv_sec= (long)(_100ns.QuadPart/10000000LL);
     }
 #endif
 
@@ -845,10 +863,10 @@ namespace Lum {
         throw DateOutOfRange();
       }
 
-      time.tv_sec=newTime;
-      time.tv_usec=microsecond;
+      pimpl->time.tv_sec=newTime;
+      pimpl->time.tv_usec=microsecond;
 
-      time.tv_sec-=GetDifferenceToUTC();
+      pimpl->time.tv_sec-=GetDifferenceToUTC();
       // This may not be completely true, if the UTC time and the temporary calculated
       // localtime have differnt DST settings. We should try to convert with and without
       // DST, reconvert back and see which of the both values is correct.
@@ -879,8 +897,8 @@ namespace Lum {
         throw DateOutOfRange();
       }
 
-      time.tv_sec=newTime;
-      time.tv_usec=microsecond;
+      pimpl->time.tv_sec=newTime;
+      pimpl->time.tv_usec=microsecond;
     }
 
     /**
@@ -888,14 +906,15 @@ namespace Lum {
     */
     void SystemTime::Add(const SystemTime& interval)
     {
-      time.tv_sec+=interval.time.tv_sec+(time.tv_usec + interval.time.tv_usec) / 1000000;
-      time.tv_usec=(time.tv_usec+interval.time.tv_usec) % 1000000;
+      pimpl->time.tv_sec+=interval.pimpl->time.tv_sec+
+                          (pimpl->time.tv_usec + interval.pimpl->time.tv_usec) / 1000000;
+      pimpl->time.tv_usec=(pimpl->time.tv_usec+interval.pimpl->time.tv_usec) % 1000000;
     }
 
     void SystemTime::Add(time_t seconds, long microseconds)
     {
-      time.tv_sec+=seconds+(time.tv_usec + microseconds) / 1000000;
-      time.tv_usec=(time.tv_usec+microseconds) % 1000000;
+      pimpl->time.tv_sec+=seconds+(pimpl->time.tv_usec + microseconds) / 1000000;
+      pimpl->time.tv_usec=(pimpl->time.tv_usec+microseconds) % 1000000;
     }
 
     /**
@@ -903,23 +922,24 @@ namespace Lum {
     */
     void SystemTime::Sub(const SystemTime& interval)
     {
-      if (time.tv_sec<interval.time.tv_sec ||
-        (time.tv_sec==interval.time.tv_sec && time.tv_usec<interval.time.tv_usec)) {
-        time.tv_sec=0;
-        time.tv_usec=0;
+      if (pimpl->time.tv_sec<interval.pimpl->time.tv_sec ||
+          (pimpl->time.tv_sec==interval.pimpl->time.tv_sec &&
+           pimpl->time.tv_usec<interval.pimpl->time.tv_usec)) {
+        pimpl->time.tv_sec=0;
+        pimpl->time.tv_usec=0;
         return;
       }
 
 
-      if (time.tv_usec<interval.time.tv_usec) {
-        time.tv_usec=time.tv_usec+1000000-interval.time.tv_usec;
-        time.tv_sec--;
+      if (pimpl->time.tv_usec<interval.pimpl->time.tv_usec) {
+        pimpl->time.tv_usec=pimpl->time.tv_usec+1000000-interval.pimpl->time.tv_usec;
+        pimpl->time.tv_sec--;
       }
       else {
-        time.tv_usec=time.tv_usec-interval.time.tv_usec;
+        pimpl->time.tv_usec=pimpl->time.tv_usec-interval.pimpl->time.tv_usec;
       }
 
-      time.tv_sec-=interval.time.tv_sec;
+      pimpl->time.tv_sec-=interval.pimpl->time.tv_sec;
     }
 
     /**
@@ -970,57 +990,59 @@ namespace Lum {
 
     bool operator<(const SystemTime& a, const SystemTime& b)
     {
-      if (a.time.tv_sec==b.time.tv_sec) {
-        return a.time.tv_usec<b.time.tv_usec;
+      if (a.pimpl->time.tv_sec==b.pimpl->time.tv_sec) {
+        return a.pimpl->time.tv_usec<b.pimpl->time.tv_usec;
       }
       else {
-        return a.time.tv_sec<b.time.tv_sec;
+        return a.pimpl->time.tv_sec<b.pimpl->time.tv_sec;
       }
     }
 
     bool operator<=(const SystemTime& a, const SystemTime& b)
     {
-      if (a.time.tv_sec==b.time.tv_sec) {
-        return a.time.tv_usec<=b.time.tv_usec;
+      if (a.pimpl->time.tv_sec==b.pimpl->time.tv_sec) {
+        return a.pimpl->time.tv_usec<=b.pimpl->time.tv_usec;
       }
       else {
-        return a.time.tv_sec<=b.time.tv_sec;
+        return a.pimpl->time.tv_sec<=b.pimpl->time.tv_sec;
       }
     }
 
     bool operator==(const SystemTime& a, const SystemTime& b)
     {
-      return a.time.tv_sec==b.time.tv_sec && a.time.tv_usec==b.time.tv_usec;
+      return a.pimpl->time.tv_sec==b.pimpl->time.tv_sec &&
+             a.pimpl->time.tv_usec==b.pimpl->time.tv_usec;
     }
 
     bool operator!=(const SystemTime& a, const SystemTime& b)
     {
-      return a.time.tv_sec!=b.time.tv_sec || a.time.tv_usec!=b.time.tv_usec;
+      return a.pimpl->time.tv_sec!=b.pimpl->time.tv_sec ||
+             a.pimpl->time.tv_usec!=b.pimpl->time.tv_usec;
     }
 
     bool operator>=(const SystemTime& a, const SystemTime& b)
     {
-      if (a.time.tv_sec==b.time.tv_sec) {
-        return a.time.tv_usec>=b.time.tv_usec;
+      if (a.pimpl->time.tv_sec==b.pimpl->time.tv_sec) {
+        return a.pimpl->time.tv_usec>=b.pimpl->time.tv_usec;
       }
       else {
-        return a.time.tv_sec>=b.time.tv_sec;
+        return a.pimpl->time.tv_sec>=b.pimpl->time.tv_sec;
       }
     }
 
     bool operator>(const SystemTime& a, const SystemTime& b)
     {
-      if (a.time.tv_sec==b.time.tv_sec) {
-        return a.time.tv_usec>b.time.tv_usec;
+      if (a.pimpl->time.tv_sec==b.pimpl->time.tv_sec) {
+        return a.pimpl->time.tv_usec>b.pimpl->time.tv_usec;
       }
       else {
-        return a.time.tv_sec>b.time.tv_sec;
+        return a.pimpl->time.tv_sec>b.pimpl->time.tv_sec;
       }
     }
 
     long operator-(const SystemTime& a, const SystemTime& b)
     {
-      return a.time.tv_sec-b.time.tv_sec;
+      return a.pimpl->time.tv_sec-b.pimpl->time.tv_sec;
     }
 
     Timer::Timer()
@@ -1066,25 +1088,6 @@ namespace Lum {
       }
     }
 
-    void Timer::GetTimeval(timeval& t)
-    {
-      if (!start.IsValid()) {
-        time.GetTimeval(t);
-      }
-      else {
-        SystemTime tmp,current;
-
-        current.SetToNow();
-
-        current.Sub(start);
-
-        tmp=time;
-        tmp.Add(current);
-
-        tmp.GetTimeval(t);
-      }
-    }
-
     bool Timer::IsStarted() const
     {
       return start.IsValid();
