@@ -260,6 +260,7 @@ namespace Lum {
         }
       }
 
+      size_t index=1;
       for (std::list<Def::OneOfN::Choice>::const_iterator choice=oneOfN->GetOneOfN().GetChoices().begin();
            choice!=oneOfN->GetOneOfN().GetChoices().end();
            ++choice) {
@@ -267,7 +268,7 @@ namespace Lum {
           menu->AddRadioItem(choice->GetDesc().GetLabel(),
                              /*radio->GetImage(),*/
                              oneOfN->GetOneOfN().GetValue(),
-                             choice->GetValue(),
+                             index,
                              choice->GetDesc().GetShortcutQualifier(),
                              choice->GetDesc().GetShortcutKey());
         }
@@ -275,8 +276,10 @@ namespace Lum {
           menu->AddRadioItem(choice->GetDesc().GetLabel(),
                              /*radio->GetImage(),*/
                              oneOfN->GetOneOfN().GetValue(),
-                             choice->GetValue());
+                             index);
         }
+
+        index++;
       }
     }
     else if (dynamic_cast<Def::MenuSeparator*>(item)!=NULL) {
@@ -409,6 +412,11 @@ namespace Lum {
     Redraw();
   }
 
+  Menu* MenuStrip::GetSelection() const
+  {
+    return selection;
+  }
+
   /**
     Select the previous entry in the menu strip.
   */
@@ -576,9 +584,9 @@ namespace Lum {
     Before drawing a child, find out, if it is currently selected and make it
     drawn selected, if it is.
   */
-  void MenuStrip::PreDrawChild(Object* child)
+  void MenuStrip::PreDrawChild(OS::DrawInfo* draw,
+                               Object* child)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
     std::list<PullDownMenu*>::iterator label=FindLabel(selection);
     if (label!=list.end() && child==*label) {
       draw->selected=true;
@@ -588,10 +596,9 @@ namespace Lum {
   /**
     Reverts @oproc{MenuStrip.PreDrawChild}.
   */
-  void MenuStrip::PostDrawChild(Object* /*child*/)
+  void MenuStrip::PostDrawChild(OS::DrawInfo* draw,
+                                Object* /*child*/)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->selected=false;
   }
 
@@ -728,11 +735,13 @@ namespace Lum {
   void PullDownMenu::PrepareForBackground(OS::DrawInfo* draw)
   {
     draw->activated=IsMouseActive();
+    draw->selected=strip!=NULL && subMenu!=NULL && strip->GetSelection()==subMenu;
   }
 
-  void PullDownMenu::Draw(int x, int y, size_t w, size_t h)
+  void PullDownMenu::Draw(OS::DrawInfo* draw,
+                          int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -740,10 +749,8 @@ namespace Lum {
 
     /* ---- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->activated=IsMouseActive();
-    label->Draw(x,y,w,h);
+    label->Draw(draw,x,y,w,h);
     draw->activated=false;
   }
 
@@ -902,23 +909,23 @@ namespace Lum {
     }
   }
 
-  void MenuEntry::DrawLabel(OS::DrawInfo* /*draw*/)
+  void MenuEntry::DrawLabel(OS::DrawInfo* draw)
   {
     if (label!=NULL) {
       // Left align label
       label->Move(x2,y+(height-label->GetOHeight()) / 2);
-      label->Draw(x,y,width,height);
+      label->Draw(draw,x,y,width,height);
     }
   }
 
-  void MenuEntry::DrawShortcut(OS::DrawInfo* /*draw*/)
+  void MenuEntry::DrawShortcut(OS::DrawInfo* draw)
   {
     if (shortcut!=NULL &&
         OS::display->GetTheme()->ShowKeyShortcuts()) {
       // Right align shortcut
       shortcut->Move(x3+w3-shortcut->GetOWidth(),
                      y+(height-shortcut->GetOHeight()) / 2);
-      shortcut->Draw(x,y,width,height);
+      shortcut->Draw(draw,x,y,width,height);
     }
   }
 
@@ -1032,9 +1039,10 @@ namespace Lum {
     draw->selected=menuWindow->selected==this;
   }
 
-  void ActionItem::Draw(int x, int y, size_t w, size_t h)
+  void ActionItem::Draw(OS::DrawInfo* draw,
+                        int x, int y, size_t w, size_t h)
   {
-    MenuEntry::Draw(x,y,w,h);
+    MenuEntry::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -1042,8 +1050,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->disabled=(!action.Valid() || !action->IsEnabled());
     draw->selected=menuWindow->selected==this;
 
@@ -1070,9 +1076,10 @@ namespace Lum {
     MenuEntry::CalcSize();
   }
 
-  void SeparatorItem::Draw(int x, int y, size_t w, size_t h)
+  void SeparatorItem::Draw(OS::DrawInfo* draw,
+                           int x, int y, size_t w, size_t h)
   {
-    MenuEntry::Draw(x,y,w,h);
+    MenuEntry::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -1081,7 +1088,6 @@ namespace Lum {
     /* --- */
 
     OS::ImageRef divider=OS::display->GetImage(OS::Display::menuDividerImageIndex);
-    OS::DrawInfo *draw=GetDrawInfo();
 
     divider->DrawStretched(draw,
                            this->x,this->y+(height-divider->GetHeight())/2,
@@ -1137,9 +1143,10 @@ namespace Lum {
     draw->selected=menuWindow->selected==this;
   }
 
-  void SubMenu::Draw(int x, int y, size_t w, size_t h)
+  void SubMenu::Draw(OS::DrawInfo* draw,
+                     int x, int y, size_t w, size_t h)
   {
-    MenuEntry::Draw(x,y,w,h);
+    MenuEntry::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -1147,8 +1154,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     if (menuWindow->selected==this) {
       draw->selected=true;
     }
@@ -1208,9 +1213,10 @@ namespace Lum {
     draw->selected=menuWindow->selected==this;
   }
 
-  void BoolItem::Draw(int x, int y, size_t w, size_t h)
+  void BoolItem::Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h)
   {
-    MenuEntry::Draw(x,y,w,h);
+    MenuEntry::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -1218,8 +1224,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->disabled=(!model.Valid() || !model->IsEnabled());
 
     /* Image */
@@ -1277,9 +1281,10 @@ namespace Lum {
     draw->selected=menuWindow->selected==this;
   }
 
-  void RadioItem::Draw(int x, int y, size_t w, size_t h)
+  void RadioItem::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    MenuEntry::Draw(x,y,w,h);
+    MenuEntry::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -1287,8 +1292,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     if (!model.Valid() || !model->IsEnabled()) {
       draw->disabled=true;
     }
@@ -1608,7 +1611,7 @@ namespace Lum {
 
     Observe(window->GetUnmapedAction());
     Observe(window->GetHiddenAction());
-    Observe(window->GetRedrawAction());
+    Observe(window->GetDrawAction());
     Observe(window->GetMouseOutAction());
     Observe(window->GetPreInitAction());
     Observe(window->GetEventAction());
@@ -2167,13 +2170,16 @@ namespace Lum {
   void Menu::Resync(Lum::Base::Model* model,
                     const Lum::Base::ResyncMsg& msg)
   {
-    if (model==window->GetUnmapedAction() && window->GetUnmapedAction()->IsFinished()) {
+    if (model==window->GetUnmapedAction() &&
+        window->GetUnmapedAction()->IsFinished()) {
       top->Hide();
     }
-    else if (model==window->GetHiddenAction() && window->GetHiddenAction()->IsFinished()) {
+    else if (model==window->GetHiddenAction() &&
+             window->GetHiddenAction()->IsFinished()) {
       CloseAll();
     }
-    else if (model==window->GetMouseOutAction() && window->GetMouseOutAction()->IsFinished()) {
+    else if (model==window->GetMouseOutAction() &&
+             window->GetMouseOutAction()->IsFinished()) {
       if (selected!=NULL && selected->GetSubMenu()==NULL) {
         MenuEntry *oldSelected;
 
@@ -2182,19 +2188,32 @@ namespace Lum {
         oldSelected->Redraw();
       }
     }
-    else if (model==window->GetRedrawAction() && window->GetRedrawAction()->IsFinished()) {
-      const OS::Window::RedrawMsg* redrawMsg=dynamic_cast<const OS::Window::RedrawMsg*>(&msg);
+    else if (model==window->GetDrawAction() &&
+             window->GetDrawAction()->IsFinished()) {
+      const OS::Window::DrawMsg *drawMsg=dynamic_cast<const OS::Window::DrawMsg*>(&msg);
+
+      assert(drawMsg->draw!=NULL);
 
       top->Move(0,0);
       top->Layout();
-      top->DrawBackground(window->GetDrawInfo(),redrawMsg->x,redrawMsg->y,redrawMsg->width,redrawMsg->height);
-      top->Draw(redrawMsg->x,redrawMsg->y,redrawMsg->width,redrawMsg->height);
+      top->DrawBackground(drawMsg->draw,
+                          drawMsg->x,
+                          drawMsg->y,
+                          drawMsg->width,
+                          drawMsg->height);
+      top->Draw(drawMsg->draw,
+                drawMsg->x,
+                drawMsg->y,
+                drawMsg->width,
+                drawMsg->height);
     }
-    else if (model==window->GetPreInitAction() && window->GetPreInitAction()->IsFinished()) {
+    else if (model==window->GetPreInitAction() &&
+             window->GetPreInitAction()->IsFinished()) {
       stickyMode=false;
       PreInit();
     }
-    else if (model==window->GetEventAction() && window->GetEventAction()->IsFinished()) {
+    else if (model==window->GetEventAction() &&
+             window->GetEventAction()->IsFinished()) {
       const OS::Window::EventMsg *eventMsg=dynamic_cast<const OS::Window::EventMsg*>(&msg);
 
       HandleEvent(eventMsg->event);
