@@ -34,6 +34,13 @@ namespace Lum {
 
     void Calendar::SetDate(int dayOfMonth, int month, int year)
     {
+      if (!value.isNull &&
+          value.value.GetDayOfMonth()==dayOfMonth &&
+          value.value.GetMonth()==month &&
+          value.value.GetYear()==year) {
+        return;
+      }
+
       value.value.SetDate(dayOfMonth,month,year);
       value.isNull=false;
 
