@@ -26,7 +26,7 @@
 #include <Lum/Base/String.h>
 #include <Lum/Base/Util.h>
 
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/FileSystem.h>
 
 namespace Lum {
   namespace OS {
@@ -41,7 +41,6 @@ namespace Lum {
       : scrWidth(0),scrHeight(0),workAreaWidth(0),workAreaHeight(0),
         multiClickTime(200),
         appName(L""),
-        behaviour(NULL),
         theme(NULL),
         eventLoop(NULL)
       {
@@ -95,7 +94,6 @@ namespace Lum {
         propFont=NULL;
         fixedFont=NULL;
 
-        delete behaviour;
         delete theme;
       }
 
@@ -119,28 +117,14 @@ namespace Lum {
         programName=name;
       }
 
-      void Display::SetArgs(const std::vector<std::wstring>& args)
-      {
-        this->args=args;
-      }
-
-      size_t Display::GetArgCount() const
-      {
-        return args.size();
-      }
-
-      std::wstring Display::GetArg(size_t pos) const
-      {
-        assert(pos<args.size());
-
-        return args[pos];
-      }
-
       std::wstring Display::GetThemePath() const
       {
+        std::wstring    dir;
         Lum::Base::Path path;
 
-        path.SetNativeDir(::Lum::Base::Path::GetHome());
+        Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::userDir,dir);
+
+        path.SetNativeDir(dir);
         path.AppendDir(L".illumination");
         path.AppendDir(L"themes");
 
@@ -157,11 +141,6 @@ namespace Lum {
         return path.GetPath();
       }
 
-      Behaviour* Display::GetBehaviour() const
-      {
-        return behaviour;
-      }
-
       Theme* Display::GetTheme() const
       {
         return theme;
@@ -668,9 +647,9 @@ namespace Lum {
         return NULL;
       }
 
-      Manager::KeyboardManager* Display::GetKeyboardManager() const
+      Manager::Keyboard* Display::GetKeyboardManager() const
       {
-        return Manager::repository->GetKeyboardManager();
+        return Manager::Keyboard::Instance();
       }
 
       OS::Display::ByteOrder Display::GetSystemByteOrder() const
