@@ -40,7 +40,7 @@
 
 #include <Lum/OS/Cairo/Bitmap.h>
 #include <Lum/OS/Cairo/Font.h>
-
+#include <iostream>
 namespace Lum {
   namespace OS {
     namespace Cairo {
@@ -91,7 +91,6 @@ namespace Lum {
         cairo_save(cairo);
         cairo_rectangle(cairo,x,y,width,height);
         cairo_clip(cairo);
-        cairo_new_path(cairo);
       }
 
       void DrawInfo::PushClipBegin(size_t x, size_t y, size_t width, size_t height)
@@ -115,7 +114,6 @@ namespace Lum {
       void DrawInfo::PushClipEnd()
       {
         cairo_clip(cairo);
-        cairo_new_path(cairo);
       }
 
       void DrawInfo::PopClip()
@@ -136,7 +134,9 @@ namespace Lum {
       {
         assert(font!=NULL);
 
-        if (fontStack.size()>0 && fontStack.top().font.Get()==font && fontStack.top().style==style) {
+        if (fontStack.size()>0 &&
+            fontStack.top().font.Get()==font &&
+            fontStack.top().style==style) {
           fontStack.top().count++;
         }
         else {
@@ -151,11 +151,10 @@ namespace Lum {
 
           s=dynamic_cast<Font*>(font)->GetStyle(style);
 
-          cairo_save(cairo);
-
           assert(s!=NULL);
           assert(s->fontScaled!=NULL);
 
+          cairo_save(cairo);
           cairo_set_scaled_font(cairo,s->fontScaled);
         }
       }
@@ -174,7 +173,10 @@ namespace Lum {
         }
       }
 
-      void DrawInfo::DrawString(int x, int y, const std::wstring& text, size_t start, size_t length)
+      void DrawInfo::DrawString(int x, int y,
+                                const std::wstring& text,
+                                size_t start,
+                                size_t length)
       {
         assert(fontStack.size()>0);
         assert(colorPushCount>0);
@@ -465,8 +467,8 @@ namespace Lum {
       void DrawInfo::FillPolygon(const Point points[], size_t count)
       {
         cairo_new_path(cairo);
-          cairo_move_to(cairo,points[0].x,points[0].y);
-        for (size_t x=1; x< count; x++) {
+        cairo_move_to(cairo,points[0].x,points[0].y);
+        for (size_t x=1; x<count; x++) {
           cairo_line_to(cairo,points[x].x,points[x].y);
         }
         cairo_close_path(cairo);
