@@ -30,8 +30,6 @@
 
 #include <Lum/OS/EventLoopUnix.h>
 
-#include <Lum/OS/Base/Behaviour.h>
-
 #include <Lum/OS/Curses/Font.h>
 #include <Lum/OS/Curses/Theme.h>
 #include <Lum/OS/Curses/Tray.h>
@@ -299,7 +297,6 @@ namespace Lum {
         fixedFont=fixedFont->Load();
         fixedFontSize=1;
 
-        behaviour=new OS::Base::DefaultBehaviour();
         theme=new Theme(this);
 
         for (size_t i=0; i<colorCount; i++) {
