@@ -164,7 +164,7 @@ namespace Lum {
     Mutex::Mutex()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      InitializeCriticalSection(&handle);
+      handle=CreateMutex(NULL,FALSE,NULL);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_init(&handle,NULL);
 #endif
@@ -178,7 +178,7 @@ namespace Lum {
     Mutex::~Mutex()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      DeleteCriticalSection(&handle);
+      CloseHandle(handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_destroy(&handle);
 #endif
@@ -187,7 +187,7 @@ namespace Lum {
     void Mutex::Lock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      EnterCriticalSection(&handle);
+      WaitForSingleObject(handle,INFINITE);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_lock(&handle);
 #endif
@@ -196,14 +196,14 @@ namespace Lum {
     void Mutex::Unlock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      LeaveCriticalSection(&handle);
+      ReleaseMutex(handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_unlock(&handle);
 #endif
     }
 
 #if defined(__WIN32__) || defined(WIN32)
-    CRITICAL_SECTION Mutex::GetHandle() const
+    HANDLE Mutex::GetHandle() const
     {
       return handle;
     }
@@ -217,7 +217,7 @@ namespace Lum {
     TryMutex::TryMutex()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      InitializeCriticalSection(&handle);
+      handle=CreateMutex(NULL,FALSE,NULL);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_init(&handle,NULL);
 #endif
@@ -231,7 +231,7 @@ namespace Lum {
     TryMutex::~TryMutex()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      DeleteCriticalSection(&handle);
+      CloseHandle(handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_destroy(&handle);
 #endif
@@ -240,7 +240,7 @@ namespace Lum {
     bool TryMutex::TryLock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      return TryEnterCriticalSection(&handle)!=0;
+      return WaitForSingleObject(handle,0)!=WAIT_OBJECT_0;
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       return pthread_mutex_trylock(&handle)==0;
 #endif
@@ -249,7 +249,7 @@ namespace Lum {
     void TryMutex::Lock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      EnterCriticalSection(&handle);
+      WaitForSingleObject(handle,INFINITE);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_lock(&handle);
 #endif
@@ -258,7 +258,7 @@ namespace Lum {
     void TryMutex::Unlock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      LeaveCriticalSection(&handle);
+      ReleaseMutex(handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_mutex_unlock(&handle);
 #endif
@@ -282,7 +282,7 @@ namespace Lum {
     RWMutex::~RWMutex()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      DeleteCriticalSection(&handle);
+      //DeleteCriticalSection(&handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_rwlock_destroy(&handle);
 #endif
@@ -329,7 +329,7 @@ namespace Lum {
     void RWMutex::Unlock()
     {
 #if defined(__WIN32__) || defined(WIN32)
-      LeaveCriticalSection(&handle);
+      //LeaveCriticalSection(&handle);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_rwlock_unlock(&handle);
 #endif
@@ -338,6 +338,11 @@ namespace Lum {
     Condition::Condition()
     {
 #if defined(__WIN32__) || defined(WIN32)
+      waiters_count=0;
+      was_broadcast=0;
+      sema=CreateSemaphore(NULL,0,0x7fffffff,NULL);
+      InitializeCriticalSection(&waiters_count_lock);
+      waiters_done=CreateEvent (NULL,FALSE,FALSE,NULL);
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       int result;
 
@@ -350,6 +355,11 @@ namespace Lum {
 #endif
     }
 
+    /*
+     * See http://www.cs.wustl.edu/~schmidt/win32-cv-1.html for details about
+     * the windows version of conditions
+     */
+     
     Condition::Condition(const Condition& /*other*/)
     {
       assert(true);
@@ -366,6 +376,13 @@ namespace Lum {
     void Condition::Signal()
     {
 #if defined(__WIN32__) || defined(WIN32)
+    EnterCriticalSection(&waiters_count_lock);
+    int have_waiters=waiters_count>0;
+    LeaveCriticalSection(&waiters_count_lock);
+
+    if (have_waiters) {
+      ReleaseSemaphore(sema,1,0);
+    }
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_cond_signal(&handle);
 #endif
@@ -374,6 +391,25 @@ namespace Lum {
     void Condition::Broadcast()
     {
 #if defined(__WIN32__) || defined(WIN32)
+      EnterCriticalSection(&waiters_count_lock);
+      int have_waiters=0;
+
+      if (waiters_count>0) {
+        was_broadcast=1;
+        have_waiters=1;
+      }
+
+      if (have_waiters) {
+        ReleaseSemaphore(sema,waiters_count,0);
+
+        LeaveCriticalSection(&waiters_count_lock);
+
+        WaitForSingleObject(waiters_done,INFINITE);
+        was_broadcast=0;
+      }
+      else {
+        LeaveCriticalSection(&waiters_count_lock);
+      }
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_cond_broadcast(&handle);
 #endif
@@ -382,6 +418,27 @@ namespace Lum {
     void Condition::Wait(Mutex& mutex)
     {
 #if defined(__WIN32__) || defined(WIN32)
+      // Avoid race conditions.
+      EnterCriticalSection(&waiters_count_lock);
+      waiters_count++;
+      LeaveCriticalSection(&waiters_count_lock);
+
+      SignalObjectAndWait(mutex.GetHandle(),sema,INFINITE,FALSE);
+
+      EnterCriticalSection(&waiters_count_lock);
+
+      waiters_count--;
+
+      int last_waiter = was_broadcast && waiters_count==0;
+
+      LeaveCriticalSection(&waiters_count_lock);
+
+      if (last_waiter) {
+        SignalObjectAndWait(waiters_done,mutex.GetHandle(),INFINITE,FALSE);
+      }
+      else {
+        WaitForSingleObject(mutex.GetHandle(),INFINITE);
+      }
 #elif defined(ILLUMINATION_THREAD_PTHREAD)
       pthread_cond_wait(&handle,mutex.GetHandle());
 #endif
