@@ -19,6 +19,7 @@
 
 #include <Lum/OS/Win32/Win32Theme.h>
 
+#include <algorithm>
 #include <iostream>
 
 #include <uxtheme.h>
@@ -2692,6 +2693,16 @@ namespace Lum {
         return 1;
       }
 
+      size_t Win32Theme::GetIconWidth() const
+      {
+        return 16;
+      }
+      
+      size_t Win32Theme::GetIconHeight() const
+      {
+        return 16;
+      }
+
       size_t Win32Theme::GetDragStartSensitivity() const
       {
         return 6;
