@@ -60,11 +60,14 @@
   #include <gst/gst.h>
 #endif
 
+#if defined(LUM_HAVE_LIB_HILDON)
+  #include <hildon/hildon-main.h>
+#endif
+
 #include <Lum/Base/String.h>
 
 #include <Lum/Images/Image.h>
 
-#include <Lum/OS/Base/Behaviour.h>
 #include <Lum/OS/Base/Theme.h>
 
 #include <Lum/OS/EventLoopUnix.h>
@@ -72,9 +75,6 @@
   #include <Lum/OS/EventLoopGMainLoop.h>
 #endif
 
-#include <Lum/OS/X11/DrawInfo.h>
-#include <Lum/OS/X11/Font.h>
-#include <Lum/OS/X11/Image.h>
 #include <Lum/OS/X11/Tray.h>
 #include <Lum/OS/X11/Window.h>
 
@@ -82,12 +82,8 @@
   #include <Lum/OS/X11/GtkTheme.h>
 #endif
 
-#if defined(LUM_HAVE_LIB_HILDON)
-  #include <Lum/OS/Hildon/Behaviour.h>
-#endif
-
 #if defined(CAIRO_HAS_XLIB_SURFACE)
-  #include <Lum/OS/Cairo/Display.h>
+  #include <Lum/OS/Cairo/Driver.h>
 #endif
 
 namespace Lum {
@@ -906,6 +902,10 @@ namespace Lum {
 
         gdk_threads_init();
 
+#if defined(LUM_HAVE_LIB_HILDON)
+        hildon_init();
+#endif
+	
         display=GDK_DISPLAY_XDISPLAY(gdk_display_get_default());
         scrNum=GDK_SCREEN_XNUMBER(gdk_screen_get_default());
         visual=GDK_VISUAL_XVISUAL(gdk_visual_get_system());
@@ -1035,7 +1035,7 @@ namespace Lum {
           return false;
         }
 
-        XInternAtoms(display,(char**)atomNames,atomCount,false,atoms);
+        XInternAtoms(display,const_cast<char**>(atomNames),atomCount,false,atoms);
         /*
         for (size_t i=0; i<atomCount; i++) {
           atoms[i]=XInternAtom(display,atomNames[i],False);
@@ -1051,19 +1051,12 @@ namespace Lum {
              driver->GetDriverName()==L"CairoX11")) &&
              (getenv("ILLUMINATION_THEME")==NULL ||
               strcmp(getenv("ILLUMINATION_THEME"),"X11"))!=0) {
-#if defined (LUM_HAVE_LIB_HILDON)
-          behaviour=new OS::Hildon::Behaviour();
-#else
-          behaviour=new OS::Base::DefaultBehaviour();
-#endif
           theme=new GtkTheme(this);
         }
         else {
-          behaviour=new OS::Base::DefaultBehaviour();
           theme=new OS::Base::DefaultTheme(this);
         }
 #else
-        behaviour=new OS::Base::DefaultBehaviour();
         theme=new OS::Base::DefaultTheme(this);
 #endif
 
@@ -1077,7 +1070,7 @@ namespace Lum {
         propFont=font->Load();
 
         if (!propFont.Valid()) {
-          std::cerr << "Cannot load font '" << dynamic_cast<Font*>(font.Get())->fullName << "'/"<< font->name << ", " << font->pixelHeight << "!" << std::endl;
+          std::cerr << "Cannot load font '" << font->name << ", " << font->pixelHeight << "!" << std::endl;
 #if !defined(HAVE_LIB_GTK)
           XCloseDisplay(display);
 #endif
@@ -1094,7 +1087,7 @@ namespace Lum {
         fixedFont=font->Load();
 
         if (!fixedFont.Valid()) {
-          std::cerr << "Cannot load font '" << dynamic_cast<Font*>(font.Get())->fullName << "'/"<< font->name << ", " << font->pixelHeight << "!" << std::endl;
+          std::cerr << "Cannot load font '" << font->name << ", " << font->pixelHeight << "!" << std::endl;
 #if !defined(HAVE_LIB_GTK)
           XCloseDisplay(display);
 #endif
@@ -1813,7 +1806,8 @@ namespace Lum {
           tmp=max;
           tmp.Sub(now);
 
-          tmp.GetTimeval(timeout);
+          timeout.tv_sec=tmp.GetTime();
+          timeout.tv_usec=tmp.GetMicroseconds();
 
           ret=select(x11Fd+1,&set,NULL,NULL,&timeout);
 
@@ -1864,7 +1858,8 @@ namespace Lum {
           tmp=max;
           tmp.Sub(now);
 
-          tmp.GetTimeval(timeout);
+          timeout.tv_sec=tmp.GetTime();
+          timeout.tv_usec=tmp.GetMicroseconds();
 
           ret=select(x11Fd+1,&set,NULL,NULL,&timeout);
 
