@@ -147,7 +147,7 @@ namespace Lum {
         return return;
       }
 
-      #endif
+#endif
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
@@ -647,7 +647,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
       void Window::TriggerDraw(int x, int y, size_t width, size_t height)
       {
-
         /*
           Try to optimize redrawRects list
         */
@@ -733,8 +732,10 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         for (std::vector<Rectangle>::const_iterator rect=redrawRects.begin();
              rect!=redrawRects.end();
              ++rect) {
+          // There seems to be a bug in the cairo version with hildon...
+#if !defined(LUM_HAVE_LIB_HILDON)
           draw->PushClip(rect->x,rect->y,rect->width,rect->height);
-
+#endif
           OS::Window::DrawMsg msg;
 
           msg.draw=draw;
@@ -745,7 +746,9 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
           drawAction->Trigger(msg);
 
+#if !defined(LUM_HAVE_LIB_HILDON)
           draw->PopClip();
+#endif
         }
 
         ReleaseRefreshDrawInfo(x1,y1,x2-x1+1,y2-y1+1);
