@@ -75,9 +75,10 @@ namespace Lum {
     Control::CalcSize();
   }
 
-  void PosMarker::Draw(int x, int y, size_t w, size_t h)
+  void PosMarker::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -91,9 +92,8 @@ namespace Lum {
       return;
     }
 
-    size_t       kSize,bSize;
-    int          kStart;
-    OS::DrawInfo *draw=GetDrawInfo();
+    size_t kSize,bSize;
+    int    kStart;
 
     if (vert) {
       bSize=height;
