@@ -40,16 +40,19 @@ namespace Lum {
     TabButton(size_t index, Object* object, const Model::SizeTRef& model);
     ~TabButton();
 
+    bool HandlesKeyFocus() const;
+
     void CalcSize();
     void Layout();
     void PrepareForBackground(OS::DrawInfo* draw);
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
     void Hide();
 
     bool HandleMouseEvent(const OS::MouseEvent& event);
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
-    OS::Color GetTextColor(OS::DrawInfo *draw) const;
+    OS::Color GetTextColor(OS::DrawInfo *draw, const void* child) const;
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
@@ -78,6 +81,17 @@ namespace Lum {
     delete image;
   }
 
+  bool TabButton::HandlesKeyFocus() const
+  {
+    return CanFocus() &&
+           RequestedFocus() &&
+           IsVisible() &&
+           model.Valid() &&
+           model->IsEnabled() &&
+           !model->IsNull() &&
+           model->Get()==index;
+  }
+
   void TabButton::CalcSize()
   {
     /* Let the frame calculate its size */
@@ -101,7 +115,9 @@ namespace Lum {
   bool TabButton::HandleMouseEvent(const OS::MouseEvent& event)
   {
     /* It makes no sense to get the focus if we are currently not visible */
-    if (!visible || !model.Valid() || !model->IsEnabled()) {
+    if (!visible ||
+        !model.Valid() ||
+        !model->IsEnabled()) {
       return false;
     }
 
@@ -110,7 +126,9 @@ namespace Lum {
       in the bounds of our button...
     */
 
-    if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.button==OS::MouseEvent::button1) {
+    if (event.type==OS::MouseEvent::down &&
+        PointIsIn(event) &&
+        event.button==OS::MouseEvent::button1) {
       orgIndex=model->Get();
       model->Set(index);
       return true;
@@ -160,7 +178,7 @@ namespace Lum {
     return false;
   }
 
-  OS::Color TabButton::GetTextColor(OS::DrawInfo *draw) const
+  OS::Color TabButton::GetTextColor(OS::DrawInfo *draw, const void* child) const
   {
     if (draw->selected) {
       return OS::display->GetColor(OS::Display::tabTextSelectColor);
@@ -194,9 +212,10 @@ namespace Lum {
     draw->focused=HasFocus();
   }
 
-  void TabButton::Draw(int x, int y, size_t w, size_t h)
+  void TabButton::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
+    Control::Draw(draw,x,y,w,h); /* We must call Draw of our superclass */
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -204,13 +223,11 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->activated=IsMouseActive();
     draw->selected=model.Valid() && !model->IsNull() && model->Get()==index;
     draw->focused=HasFocus();
 
-    image->Draw(x,y,w,h);
+    image->Draw(draw,x,y,w,h);
 
     draw->activated=false;
     draw->selected=false;
@@ -416,9 +433,29 @@ namespace Lum {
     Control::Layout();
   }
 
-  void Tab::Draw(int x, int y, size_t w, size_t h)
+  void Tab::Draw(OS::DrawInfo* draw,
+                 int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    if (lastDrawn!=NULL) {
+
+     /*
+        This is a little trick:
+        We must hide the old object, but we do not want it to clean up the
+        covered area, since it will be overwritten by the new object anyway.
+        So we create a clipping region that completely covers the to be drawn
+        area :-)
+      */
+      draw->PushClipBegin(lastDrawn->GetOX(),lastDrawn->GetOY(),
+                          lastDrawn->GetOWidth(),lastDrawn->GetOHeight());
+      draw->SubClipRegion(lastDrawn->GetOX(),lastDrawn->GetOY(),
+                          lastDrawn->GetOWidth(),lastDrawn->GetOHeight());
+      draw->PushClipEnd();
+      lastDrawn->Hide();
+      draw->PopClip();
+      lastDrawn=NULL;
+    }
+
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -426,7 +463,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
     OS::FrameRef tabFrame=OS::display->GetFrame(OS::Display::tabFrameIndex);
 
     // Draw frame around object area
@@ -441,31 +477,12 @@ namespace Lum {
 
   void Tab::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (model==this->model && visible) {
+    if (model==this->model &&
+        visible) {
       size_t                       pos=this->model->Get();
       std::list<Object*>::iterator iter=list.begin();
       Dialog                       *dialog=dynamic_cast<Dialog*>(GetWindow()->GetMaster());
 
-      if (lastDrawn!=NULL) {
-        OS::DrawInfo *draw=GetDrawInfo();
-
-       /*
-          This is a little trick:
-          We must hide the old object, but we do not want it to clean up the
-          covered area, since it will be overwritten by the new object anyway.
-          So we create a clipping region that completely covers the to be drawn
-          area :-)
-        */
-        draw->PushClipBegin(lastDrawn->GetOX(),lastDrawn->GetOY(),
-                            lastDrawn->GetOWidth(),lastDrawn->GetOHeight());
-        draw->SubClipRegion(lastDrawn->GetOX(),lastDrawn->GetOY(),
-                            lastDrawn->GetOWidth(),lastDrawn->GetOHeight());
-        draw->PushClipEnd();
-        lastDrawn->Hide();
-        draw->PopClip();
-        lastDrawn=NULL;
-      }
-
       Redraw();
 
       if (dialog!=NULL) {
