@@ -24,12 +24,12 @@
 #include <Lum/Base/String.h>
 #include <Lum/Base/Util.h>
 
-#include <Lum/OS/Behaviour.h>
+#include <Lum/Manager/Behaviour.h>
+#include <Lum/Manager/Keyboard.h>
+
 #include <Lum/OS/Driver.h>
 #include <Lum/OS/Theme.h>
 
-#include <Lum/OS/Manager/KeyboardManager.h>
-
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
 
@@ -139,8 +139,8 @@ namespace Lum {
       current->CatchedFocus();
     }
 
-    if (OS::display->GetKeyboardManager()!=NULL) {
-      OS::display->GetKeyboardManager()->OnFocusChange(window,oldCurrent,object);
+    if (Manager::Keyboard::Instance()!=NULL) {
+      Manager::Keyboard::Instance()->OnFocusChange(window,oldCurrent,object);
     }
   }
 
@@ -201,8 +201,10 @@ namespace Lum {
 
   void Window::KeyHandler::Activate()
   {
-    if (current!=NULL ||Lum::OS::display->GetBehaviour()->FocusObjectOnWindowFocusIn()) {
-      if (current!=NULL && current->HandlesFocus()) {
+    if (current!=NULL ||
+        Manager::Behaviour::Instance()->FocusObjectOnWindowFocusIn()) {
+      if (current!=NULL &&
+          (current->HandlesClickFocus() || current->HandlesKeyFocus())) {
         if (OS::display->GetKeyboardManager()!=NULL) {
           OS::display->GetKeyboardManager()->OnFocusChange(window,current,current);
         }
@@ -300,7 +302,8 @@ namespace Lum {
   {
     Shortcut *sc;
 
-    if (current!=NULL && current->HandleKeyEvent(*event)) {
+    if (current!=NULL &&
+      current->HandleKeyEvent(*event)) {
       return true;
     }
 
@@ -388,7 +391,7 @@ namespace Lum {
     Observe(window->GetFocusOutAction());
     Observe(window->GetMouseInAction());
     Observe(window->GetMouseOutAction());
-    Observe(window->GetRedrawAction());
+    Observe(window->GetDrawAction());
     Observe(window->GetResizeAction());
     Observe(window->GetPreInitAction());
     Observe(window->GetOpenedAction());
@@ -517,14 +520,14 @@ namespace Lum {
 
   void Window::ReinitWindow()
   {
-    main->CalcSize();
+    CalcSize();
 
     window->Resize(main->GetOWidth(),main->GetOHeight());
 
     if (IsShown() || IsOpen()) {
       // This has to be tested
       window->TriggerResize(main->GetOWidth(),main->GetOHeight());
-      window->TriggerRedraw(0,0,window->GetWidth(),window->GetHeight());
+      window->TriggerDraw(0,0,window->GetWidth(),window->GetHeight());
     }
   }
 
@@ -599,7 +602,6 @@ namespace Lum {
 
   void Window::SetFocus(Lum::Object* gadget)
   {
-    //assert(gadget==NULL || gadget->HandlesFocus());
     if (deleted) {
       // Do reassign focus if our destructor has ben called
       return;
@@ -761,7 +763,7 @@ namespace Lum {
         mouseGrabHunting=false;
 
         if (mouseGrab!=NULL &&
-            mouseGrab->HandlesFocus()) {
+            mouseGrab->HandlesClickFocus()) {
           SetFocus(dynamic_cast<Lum::Object*>(mouseGrab));
         }
       }
@@ -875,14 +877,23 @@ namespace Lum {
       main->Resize(resizeMsg->width,resizeMsg->height);
       EvaluateMouseActive();
     }
-    else if (model==window->GetRedrawAction() &&
-             window->GetRedrawAction()->IsFinished()) {
-      const OS::Window::RedrawMsg *redrawMsg=dynamic_cast<const OS::Window::RedrawMsg*>(&msg);
+    else if (model==window->GetDrawAction() &&
+             window->GetDrawAction()->IsFinished()) {
+      const OS::Window::DrawMsg *drawMsg=dynamic_cast<const OS::Window::DrawMsg*>(&msg);
+      assert(drawMsg->draw!=NULL);
 
       main->Move(0,0);
       main->Layout();
-      main->DrawBackground(window->GetDrawInfo(),redrawMsg->x,redrawMsg->y,redrawMsg->width,redrawMsg->height);
-      main->Draw(redrawMsg->x,redrawMsg->y,redrawMsg->width,redrawMsg->height);
+      main->DrawBackground(drawMsg->draw,
+                           drawMsg->x,
+                           drawMsg->y,
+                           drawMsg->width,
+                           drawMsg->height);
+      main->Draw(drawMsg->draw,
+                 drawMsg->x,
+                 drawMsg->y,
+                 drawMsg->width,
+                 drawMsg->height);
     }
     else if (model==window->GetPreInitAction() &&
              window->GetPreInitAction()->IsFinished()) {
